package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.Users;
import com.yunzhi.inte.service.UsersService;

 /**
 * 用户表;(users)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-10-12
 */
@Api(tags = "用户表对象功能接口")
@RestController
@RequestMapping("/")
public class UsersController extends BaseController {
    
    @Autowired
    private UsersService usersService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/users/current")
    public ResponseBean queryById() throws Exception {
        return ResponseBean.success(currentUser());
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/users")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<Users> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<Users> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<Users> result = usersService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param users 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/users")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody Users users) throws Exception {
        usersService.save(users);
        return ResponseBean.success(users);
    }
    
    /** 
     * 更新数据
     *
     * @param users 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/users/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody Users users,
                            @ApiParam("对象ID") @PathVariable Integer id ) throws Exception {
        usersService.updateById(users);
        return ResponseBean.success(users);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/users/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        usersService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}